==> bonita-server-6.1.1-sources.jar: org/bonitasoft/engine/platform/session/model/builder/impl/SPlatformSessionBuilderImpl.java <==
/**
 * Copyright (C) 2011 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.platform.session.model.builder.impl;

import java.util.Date;

import org.bonitasoft.engine.platform.session.model.SPlatformSession;
import org.bonitasoft.engine.platform.session.model.builder.SPlatformSessionBuilder;
import org.bonitasoft.engine.platform.session.model.impl.SPlatformSessionImpl;

/**
 * @author Elias Ricken de Medeiros
 */
public class SPlatformSessionBuilderImpl implements SPlatformSessionBuilder {

    private SPlatformSessionImpl entity;

    @Override
    public SPlatformSessionBuilder createNewInstance(final long id, final long duration, final String username) {
        this.entity = new SPlatformSessionImpl(id, username);
        this.entity.setDuration(duration);
        return this;
    }

    @Override
    public SPlatformSessionBuilder lastRenewDate(final Date lastRenewDate) {
        this.entity.setLastRenewDate(lastRenewDate);
        return this;
    }

    @Override
    public SPlatformSession done() {
        final Date now = new Date();
        this.entity.setCreationDate(now);
        this.entity.setLastRenewDate(now);
        return this.entity;
    }

    @Override
    public SPlatformSession copy(final SPlatformSession session) {
        return new SPlatformSessionImpl(session);
    }

}

==> bonita-server-6.3.2-sources.jar: org/bonitasoft/engine/platform/session/model/builder/impl/SPlatformSessionBuilderImpl.java <==
/**
 * Copyright (C) 2011 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.platform.session.model.builder.impl;

import java.util.Date;

import org.bonitasoft.engine.platform.session.model.SPlatformSession;
import org.bonitasoft.engine.platform.session.model.builder.SPlatformSessionBuilder;
import org.bonitasoft.engine.platform.session.model.impl.SPlatformSessionImpl;

/**
 * @author Elias Ricken de Medeiros
 */
public class SPlatformSessionBuilderImpl implements SPlatformSessionBuilder {

    private final SPlatformSessionImpl entity;
    
    public SPlatformSessionBuilderImpl(final SPlatformSessionImpl entity) {
        super();
        this.entity = entity;
    }

    @Override
    public SPlatformSessionBuilder lastRenewDate(final Date lastRenewDate) {
        this.entity.setLastRenewDate(lastRenewDate);
        return this;
    }

    @Override
    public SPlatformSession done() {
        final Date now = new Date();
        this.entity.setCreationDate(now);
        this.entity.setLastRenewDate(now);
        return this.entity;
    }

}
